@@ -66,13 +66,25 @@ class BrokerStreams():
             raise traceback.format_exc()
 
 
-class Connectors(Enum):
-    INSTA = 'INSTA'
-    LINKEDIN = 'LINKEDIN'   
-    FACEBOOK = 'FACEBOOK'
+consumerNames = [
+    'c.internal.extractor.insta',
+    'c.internal.extractor.facebook',
+    'c.internal.extractor.linkedin',
+    'c.internal.transform.facebook',
+    'c.internal.transform.insta',
+    'c.internal.transform.linkedin',
+    'c.internal.graph.create',
+]
+
+providerNames = [
+    'p.internal.transform.insta',
+    'p.internal.transform.facebook',
+    'p.internal.transform.linkedin',
+    'p.internal.graph.create'
+]
 
 class StatusSearch(Enum):
-    RUNNING = 'RUNNING'
+    PROGRESS = 'PROGRESS'
     FAILED = 'FAILED'
     SUCCESS = 'SUCCESS'
 
@@ -82,7 +94,7 @@ class SearchType(Enum):
     LINK = 'LINK'
 
 @dataclasses.dataclass
-class DtoBk:
+class QueueMessageDTO:
     user_id: str
     search_id: str
     search_type: list  
